BlePeripheralChannel class

Flutter -> Native

Constructors

BlePeripheralChannel({BinaryMessenger? binaryMessenger})
Constructor for BlePeripheralChannel. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addService(BleService service) Future<void>
askBlePermission() Future<bool>
clearServices() Future<void>
getServices() Future<List<String?>>
getSubscribedClients() Future<List<SubscribedClient?>>
initialize() Future<void>
isAdvertising() Future<bool?>
isSupported() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeService(String serviceId) Future<void>
startAdvertising(List<String?> services, String? localName, int? timeout, ManufacturerData? manufacturerData, bool addManufacturerDataInScanResponse, bool requireBonding) Future<void>
stopAdvertising() Future<void>
toString() String
A string representation of this object.
inherited
updateCharacteristic(String characteristicId, Uint8List value, String? deviceId) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>